"""
Init for file for meta package.
"""
# flake8: noqa

from .meta import Meta
